### Что это?

Это простой парсер в форматы .csv и .xlsx для данных, выгружаемых из истории операций по карте одного банка. Написано и предназначено для личного использования: я веду учёт личных финансов в таблице и устал забивать руками каждый платёж по карте.

Программа не производит никаких взаимодействий с сайтом банка и личным кабинетом клиента по сети, не использует чужие данные и вообще не даёт доступа ни к чему такому, к чему изначально нет доступа у пользователя. Функционал программы ограничен предоставлением данных, изначально доступных пользователю, в удобной форме таблицы.

### Как использовать?

1. Заходим в личный кабинет в историю операций по карте. Кликаем на кнопку "Отчёт по карте". Настраиваем период, за который нужна выгрузка. Сохраняем страницу средствами браузера.
2. Открываем консоль, заходим в папку сохраненной страницы с окончанием "_files". Приложению для работы нужен файл index.html, он находится в данной папке. Копируем этот файл в корень папки со скриптом.
3. Запускаем скрипт (требуется установка poetry):
```
pip install poetry
make start
```
4. Если всё прошло успешно, то в этой же папке появятся файлы transactions с расширениями .csv и .xlsx со списком транзакций

### TODO
Сделать консольное приложение с возможностью выбора формата
  